==> qtjambi-activex-6.3.2-sources.jar: io/qt/activex/QAxBaseWidget.java <==
package io.qt.activex;


/**
 * <p>Static properties and signals for QAxWidget</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qaxbasewidget.html">QAxBaseWidget</a></p>
 */
public abstract class QAxBaseWidget extends io.qt.widgets.QWidget
    implements io.qt.activex.QAxObjectInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxBaseWidget.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAxBaseWidget {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int classContext(){
            return classContext_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static int classContext_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String control(){
            return control_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.lang.String control_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void resetControl(){
            resetControl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static void resetControl_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setClassContext(int classContext){
            setClassContext_native_ulong(QtJambi_LibraryUtilities.internal.nativeId(this), classContext);
        }
        private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean setControl(java.lang.String c){
            return setControl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), c);
        }
        private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#exception">QAxBaseWidget::exception(int,QString,QString,QString)</a></p>
     */
    public final Signal4<@io.qt.QtPrimitiveType Integer, java.lang.String, java.lang.String, java.lang.String> exception = new Signal4<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#propertyChanged">QAxBaseWidget::propertyChanged(QString)</a></p>
     */
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#signal">QAxBaseWidget::signal(QString,int,void*)</a></p>
     */
    private final Signal3<java.lang.String, @io.qt.QtPrimitiveType Integer, io.qt.QNativePointer> signal = new Signal3<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    protected QAxBaseWidget(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... f){
        this(parent, new io.qt.core.Qt.WindowFlags(f));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>f = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    protected QAxBaseWidget(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}</p>
     * <p>with: </p><ul>
     * <li><code>parent = null</code></li>
     * <li><code>f = new io.qt.core.Qt.WindowFlags(0)</code></li>
     * </ul>
     */
    protected QAxBaseWidget() {
        this((io.qt.widgets.QWidget)null, new io.qt.core.Qt.WindowFlags(0));
    }
    
    protected QAxBaseWidget(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags f){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, f);
    }
    
    private native static void initialize_native(QAxBaseWidget instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags f);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#classContext">QAxObjectInterface::classContext()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int classContext();
    
    private native static int classContext_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#control">QAxObjectInterface::control()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.lang.String control();
    
    private native static java.lang.String control_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#resetControl">QAxObjectInterface::resetControl()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void resetControl();
    
    private native static void resetControl_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setClassContext">QAxObjectInterface::setClassContext(ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void setClassContext(int classContext);
    
    private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setControl">QAxObjectInterface::setControl(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean setControl(java.lang.String c);
    
    private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxBaseWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxBaseWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxBaseWidget instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-activex-6.4.0-sources.jar: io/qt/activex/QAxBaseWidget.java <==
package io.qt.activex;


/**
 * <p>Static properties and signals for QAxWidget</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qaxbasewidget.html">QAxBaseWidget</a></p>
 */
public abstract class QAxBaseWidget extends io.qt.widgets.QWidget
    implements io.qt.activex.QAxObjectInterface
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAxBaseWidget.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAxBaseWidget {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public int classContext(){
            return classContext_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static int classContext_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public java.lang.String control(){
            return control_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static java.lang.String control_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void resetControl(){
            resetControl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        private native static void resetControl_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setClassContext(int classContext){
            setClassContext_native_ulong(QtJambi_LibraryUtilities.internal.nativeId(this), classContext);
        }
        private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
        
        
        @Override
        @io.qt.QtUninvokable
        public boolean setControl(java.lang.String c){
            return setControl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), c);
        }
        private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#exception">QAxBaseWidget::exception(int,QString,QString,QString)</a></p>
     */
    public final Signal4<@io.qt.QtPrimitiveType Integer, java.lang.String, java.lang.String, java.lang.String> exception = new Signal4<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#propertyChanged">QAxBaseWidget::propertyChanged(QString)</a></p>
     */
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxbasewidget.html#signal">QAxBaseWidget::signal(QString,int,void*)</a></p>
     */
    private final Signal3<java.lang.String, @io.qt.QtPrimitiveType Integer, io.qt.QNativePointer> signal = new Signal3<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    protected QAxBaseWidget(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... f){
        this(parent, new io.qt.core.Qt.WindowFlags(f));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>f = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    protected QAxBaseWidget(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QAxBaseWidget(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}</p>
     * <p>with: </p><ul>
     * <li><code>parent = null</code></li>
     * <li><code>f = new io.qt.core.Qt.WindowFlags(0)</code></li>
     * </ul>
     */
    protected QAxBaseWidget() {
        this((io.qt.widgets.QWidget)null, new io.qt.core.Qt.WindowFlags(0));
    }
    
    protected QAxBaseWidget(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags f){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, f);
    }
    
    private native static void initialize_native(QAxBaseWidget instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags f);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#classContext">QAxObjectInterface::classContext()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract int classContext();
    
    private native static int classContext_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#control">QAxObjectInterface::control()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract java.lang.String control();
    
    private native static java.lang.String control_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#resetControl">QAxObjectInterface::resetControl()</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void resetControl();
    
    private native static void resetControl_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setClassContext">QAxObjectInterface::setClassContext(ulong)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void setClassContext(int classContext);
    
    private native static void setClassContext_native_ulong(long __this__nativeId, int classContext);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qaxobjectinterface.html#setControl">QAxObjectInterface::setControl(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract boolean setControl(java.lang.String c);
    
    private native static boolean setControl_native_cref_QString(long __this__nativeId, java.lang.String c);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAxBaseWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAxBaseWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAxBaseWidget instance, QDeclarativeConstructor constructor);
    
}
